## CMR Connectors Library
This library returns connectors to use in your projects from different databases.


## Push to pypi
```bash
pip install wheel
python setup.py sdist bdist_wheel
pip install twine
twine upload dist/*
```